==> itk-meshtopolydata-0.6.0-py37hc8dfbb8_0.tar.bz2: Lib/site-packages/itk/Configuration/MeshToPolyDataConfig.py <==
depends = ('ITKPyBase', 'ITKMesh', 'ITKCommon', )
templates = (
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterISS2PSSS2', True, 'itk::Image< signed short,2 >, itk::PointSet < signed short,2 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterISS3PSSS3', True, 'itk::Image< signed short,3 >, itk::PointSet < signed short,3 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterIUC2PSUC2', True, 'itk::Image< unsigned char,2 >, itk::PointSet < unsigned char,2 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterIUC3PSUC3', True, 'itk::Image< unsigned char,3 >, itk::PointSet < unsigned char,3 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterIUS2PSUS2', True, 'itk::Image< unsigned short,2 >, itk::PointSet < unsigned short,2 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterIUS3PSUS3', True, 'itk::Image< unsigned short,3 >, itk::PointSet < unsigned short,3 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterIF2PSF2', True, 'itk::Image< float,2 >, itk::PointSet < float,2 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterIF3PSF3', True, 'itk::Image< float,3 >, itk::PointSet < float,3 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterID2PSD2', True, 'itk::Image< double,2 >, itk::PointSet < double,2 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterID3PSD3', True, 'itk::Image< double,3 >, itk::PointSet < double,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMSS2', True, 'itk::Mesh< signed short,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSSS2', True, 'itk::PointSet< signed short,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMUC2', True, 'itk::Mesh< unsigned char,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSUC2', True, 'itk::PointSet< unsigned char,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMUS2', True, 'itk::Mesh< unsigned short,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSUS2', True, 'itk::PointSet< unsigned short,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMF2', True, 'itk::Mesh< float,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSF2', True, 'itk::PointSet< float,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMD2', True, 'itk::Mesh< double,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSD2', True, 'itk::PointSet< double,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMSS3', True, 'itk::Mesh< signed short,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSSS3', True, 'itk::PointSet< signed short,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMUC3', True, 'itk::Mesh< unsigned char,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSUC3', True, 'itk::PointSet< unsigned char,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMUS3', True, 'itk::Mesh< unsigned short,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSUS3', True, 'itk::PointSet< unsigned short,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMF3', True, 'itk::Mesh< float,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSF3', True, 'itk::PointSet< float,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMD3', True, 'itk::Mesh< double,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSD3', True, 'itk::PointSet< double,3 >'),
  ('PolyData', 'itk::PolyData', 'itkPolyDataSS', True, 'signed short'),
  ('PolyData', 'itk::PolyData', 'itkPolyDataUC', True, 'unsigned char'),
  ('PolyData', 'itk::PolyData', 'itkPolyDataUS', True, 'unsigned short'),
  ('PolyData', 'itk::PolyData', 'itkPolyDataF', True, 'float'),
  ('PolyData', 'itk::PolyData', 'itkPolyDataD', True, 'double'),
  ('PyVectorContainer', 'itk::PyVectorContainer', 'itkPyVectorContainerSS', False, 'signed short'),
  ('PyVectorContainer', 'itk::PyVectorContainer', 'itkPyVectorContainerUC', False, 'unsigned char'),
  ('PyVectorContainer', 'itk::PyVectorContainer', 'itkPyVectorContainerUS', False, 'unsigned short'),
  ('PyVectorContainer', 'itk::PyVectorContainer', 'itkPyVectorContainerF', False, 'float'),
  ('PyVectorContainer', 'itk::PyVectorContainer', 'itkPyVectorContainerD', False, 'double'),
  ('PyVectorContainer', 'itk::PyVectorContainer', 'itkPyVectorContainerUI', False, 'unsigned int'),
  ('PyVectorContainer', 'itk::PyVectorContainer', 'itkPyVectorContainerPF2', False, 'itk::Point< float,2 >'),
  ('PyVectorContainer', 'itk::PyVectorContainer', 'itkPyVectorContainerPF3', False, 'itk::Point< float,3 >'),
)
snake_case_functions = ('image_to_point_set_filter', 'mesh_to_poly_data_filter', )

==> itk-meshtopolydata-0.6.2-py37hc8dfbb8_0.tar.bz2: Lib/site-packages/itk/Configuration/MeshToPolyDataConfig.py <==
depends = ('ITKPyBase', 'ITKMesh', 'ITKCommon', )
templates = (
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterISS2PSSS2', True, 'itk::Image< signed short,2 >, itk::PointSet < signed short,2 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterISS3PSSS3', True, 'itk::Image< signed short,3 >, itk::PointSet < signed short,3 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterIUC2PSUC2', True, 'itk::Image< unsigned char,2 >, itk::PointSet < unsigned char,2 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterIUC3PSUC3', True, 'itk::Image< unsigned char,3 >, itk::PointSet < unsigned char,3 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterIUS2PSUS2', True, 'itk::Image< unsigned short,2 >, itk::PointSet < unsigned short,2 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterIUS3PSUS3', True, 'itk::Image< unsigned short,3 >, itk::PointSet < unsigned short,3 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterIF2PSF2', True, 'itk::Image< float,2 >, itk::PointSet < float,2 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterIF3PSF3', True, 'itk::Image< float,3 >, itk::PointSet < float,3 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterID2PSD2', True, 'itk::Image< double,2 >, itk::PointSet < double,2 >'),
  ('ImageToPointSetFilter', 'itk::ImageToPointSetFilter', 'itkImageToPointSetFilterID3PSD3', True, 'itk::Image< double,3 >, itk::PointSet < double,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMSS2', True, 'itk::Mesh< signed short,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSSS2', True, 'itk::PointSet< signed short,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMUC2', True, 'itk::Mesh< unsigned char,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSUC2', True, 'itk::PointSet< unsigned char,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMUS2', True, 'itk::Mesh< unsigned short,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSUS2', True, 'itk::PointSet< unsigned short,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMF2', True, 'itk::Mesh< float,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSF2', True, 'itk::PointSet< float,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMD2', True, 'itk::Mesh< double,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSD2', True, 'itk::PointSet< double,2 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMSS3', True, 'itk::Mesh< signed short,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSSS3', True, 'itk::PointSet< signed short,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMUC3', True, 'itk::Mesh< unsigned char,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSUC3', True, 'itk::PointSet< unsigned char,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMUS3', True, 'itk::Mesh< unsigned short,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSUS3', True, 'itk::PointSet< unsigned short,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMF3', True, 'itk::Mesh< float,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSF3', True, 'itk::PointSet< float,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterMD3', True, 'itk::Mesh< double,3 >'),
  ('MeshToPolyDataFilter', 'itk::MeshToPolyDataFilter', 'itkMeshToPolyDataFilterPSD3', True, 'itk::PointSet< double,3 >'),
  ('PolyData', 'itk::PolyData', 'itkPolyDataSS', True, 'signed short'),
  ('PolyData', 'itk::PolyData', 'itkPolyDataUC', True, 'unsigned char'),
  ('PolyData', 'itk::PolyData', 'itkPolyDataUS', True, 'unsigned short'),
  ('PolyData', 'itk::PolyData', 'itkPolyDataF', True, 'float'),
  ('PolyData', 'itk::PolyData', 'itkPolyDataD', True, 'double'),
  ('PyVectorContainer', 'itk::PyVectorContainer', 'itkPyVectorContainerSS', False, 'signed short'),
  ('PyVectorContainer', 'itk::PyVectorContainer', 'itkPyVectorContainerUC', False, 'unsigned char'),
  ('PyVectorContainer', 'itk::PyVectorContainer', 'itkPyVectorContainerUS', False, 'unsigned short'),
  ('PyVectorContainer', 'itk::PyVectorContainer', 'itkPyVectorContainerF', False, 'float'),
  ('PyVectorContainer', 'itk::PyVectorContainer', 'itkPyVectorContainerD', False, 'double'),
  ('PyVectorContainer', 'itk::PyVectorContainer', 'itkPyVectorContainerUI', False, 'unsigned int'),
  ('PyVectorContainer', 'itk::PyVectorContainer', 'itkPyVectorContainerPF2', False, 'itk::Point< float,2 >'),
  ('PyVectorContainer', 'itk::PyVectorContainer', 'itkPyVectorContainerPF3', False, 'itk::Point< float,3 >'),
)
snake_case_functions = ('mesh_to_poly_data_filter', 'image_to_point_set_filter', )
